==> automata-serialization-taf-0.7.1-sources.jar: net/automatalib/serialization/taf/parser/PrintStreamDiagnosticListener.java <==
/* Copyright (C) 2013-2018 TU Dortmund
 * This file is part of AutomataLib, http://www.automatalib.net/.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.automatalib.serialization.taf.parser;

import java.io.PrintStream;
import java.text.MessageFormat;

public class PrintStreamDiagnosticListener implements TAFParseDiagnosticListener {

    private static final PrintStreamDiagnosticListener STDERR_INSTANCE = new PrintStreamDiagnosticListener(System.err);
    private final PrintStream ps;

    public PrintStreamDiagnosticListener(PrintStream ps) {
        this.ps = ps;
    }

    public static TAFParseDiagnosticListener getStderrDiagnosticListener() {
        return STDERR_INSTANCE;
    }

    @Override
    public void error(int line, int col, String msgFmt, Object... args) {
        ps.printf("Error: at line %d, column %d: %s\n", line, col, MessageFormat.format(msgFmt, args));
        ps.flush();
    }

    @Override
    public void warning(int line, int col, String msgFmt, Object... args) {
        ps.printf("Warning: at line %d, column %d: %s\n", line, col, MessageFormat.format(msgFmt, args));
        ps.flush();
    }

}

==> automata-serialization-taf-0.8.0-sources.jar: net/automatalib/serialization/taf/parser/PrintStreamDiagnosticListener.java <==
/* Copyright (C) 2013-2019 TU Dortmund
 * This file is part of AutomataLib, http://www.automatalib.net/.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.automatalib.serialization.taf.parser;

import java.io.PrintStream;
import java.text.MessageFormat;

public class PrintStreamDiagnosticListener implements TAFParseDiagnosticListener {

    private static final PrintStreamDiagnosticListener STDERR_INSTANCE = new PrintStreamDiagnosticListener(System.err);
    private final PrintStream ps;

    public PrintStreamDiagnosticListener(PrintStream ps) {
        this.ps = ps;
    }

    public static TAFParseDiagnosticListener getStderrDiagnosticListener() {
        return STDERR_INSTANCE;
    }

    @Override
    public void error(int line, int col, String msgFmt, Object... args) {
        ps.printf("Error: at line %d, column %d: %s%n", line, col, MessageFormat.format(msgFmt, args));
        ps.flush();
    }

    @Override
    public void warning(int line, int col, String msgFmt, Object... args) {
        ps.printf("Warning: at line %d, column %d: %s%n", line, col, MessageFormat.format(msgFmt, args));
        ps.flush();
    }

}
